@@ -22,13 +22,14 @@ import os
 import uuid
 
 from cryptography.fernet import InvalidToken
-from hspylib.core.tools.commons import sysout, syserr, file_is_not_empty, touch_file, safe_del_file
+from hspylib.core.tools.commons import file_is_not_empty, safe_del_file, syserr, sysout, touch_file
 from hspylib.modules.cli.tui.menu.menu_utils import MenuUtils
 from hspylib.modules.security.security import decrypt, encrypt
+
 from vault.core.vault_config import VaultConfig
 from vault.core.vault_service import VaultService
 from vault.entity.vault_entry import VaultEntry
-from vault.exception.exceptions import VaultOpenError, VaultCloseError
+from vault.exception.exceptions import VaultCloseError, VaultOpenError
 
 
 class Vault:
